@@ -185,7 +185,7 @@ beta.nb <- function(xnew = NULL, x, ina) {
     score <- matrix(0, dim(xnew)[1], k)
     xnew <- t(xnew)
     com <-  - Rfast::rowsums( lbeta(a, b) ) + log(ni)
-    for (i in 1:k)  score[, i] <- Rfast::colsums( (a[i, ] - 1) * log(xnew) + (b[i, ] - 1) * log(1 - xnew) )
+    for (i in 1:k)  score[, i] <- Rfast::colsums( (a[i, ] - 1) * log(xnew) + (b[i, ] - 1) * log(1 - xnew) ) 
     score <- Rfast::eachrow(score, com, oper = "+")
     est <- Rfast::rowMaxs(score)
   }
@@ -205,7 +205,6 @@ betanb.pred <- function(xnew, a, b, ni) {
 }
 
 
-
 #[export]
 cauchy.nb <- function(xnew = NULL, x, ina) {
   est <- NULL
@@ -336,3 +335,117 @@ spmlnb.pred <- function(xnew, mu1, mu2, ni) {
   Rfast::rowMaxs(score)
 }
 
+
+#[export]
+bernoulli.nb <- function(xnew = NULL, x, ina) {
+  est <- NULL
+  ni <- tabulate(ina)
+  ni <- ni[ni > 0]
+  k <- length(ni)
+  pi <- rowsum(x, ina) / ni
+  if ( !is.null(xnew) ) {
+    xnew <- t(xnew)
+    logpi <- log(pi)
+    log1pi <- log(1 - pi)
+    mat <- matrix(nrow = dim(xnew)[2], ncol = k)
+    for (j in 1:k)  mat[, j] <- Rfast::eachcol.apply(xnew, logpi[j, ]) + Rfast::eachcol.apply(1 - xnew, log1pi[j, ])
+    est <- Rfast::rowMaxs(mat)
+  }
+  rownames(pi) <- paste("Group", 1:k)
+  list(pi = pi, ni = ni, est = est)
+}
+
+
+#[export]
+bernoullinb.pred <- function(xnew, pi, ni) {
+  xnew <- t(xnew)
+  k <- dim(pi)[1]
+  logpi <- log(pi)
+  log1pi <- log(1 - pi)
+  mat <- matrix(nrow = dim(xnew)[2], ncol = k)
+  for (j in 1:k)  mat[, j] <- Rfast::eachcol.apply(xnew, logpi[j, ]) + Rfast::eachcol.apply(1 - xnew, log1pi[j, ])
+  Rfast::rowMaxs(mat)
+}
+
+
+
+#[export]
+nb.cv <- function(x, ina, type = "gaussian", folds = NULL, nfolds = 10, 
+                 stratified = TRUE, seed = FALSE, pred.ret = FALSE) {
+
+  ina <- as.numeric(ina)
+  if ( is.null(folds) ) { 
+    folds <- makefolds(ina, nfolds = nfolds, stratified = stratified, seed = seed)
+  } 
+  nfolds <- length(folds)
+  crit <- numeric(nfolds)
+  preds <- NULL
+  if ( pred.ret ) {
+    names <- paste("Fold", 1:nfolds)
+    preds <- sapply(names, function(x) NULL)
+  }
+
+  if ( type == "gaussian"  |  type == "gamma"  | type == "weibull"  |  type == "normlog" |
+       type == "logitnorm"  |  type == "beta"  | type == "laplace"  |  type == "cauchy"  |  
+	   type == "vm"  |  type == "spml" ) {
+	   
+    if ( type == "gaussian" ) { 
+      nb <- Rfast::gaussian.nb
+    } else if ( type == "gamma" ) {
+      nb <- Rfast::gammanb
+    } else if ( type == "weibull" ) {
+      nb <- Rfast2::weibull.nb
+    } else if (type == "normlog" ) {
+      nb <- Rfast2::normlog.nb
+    } else if ( type == "laplace" ) {
+      nb <- Rfast2::laplace.nb
+	} else if ( type == "cauchy" ) {
+      nb <- Rfast2::cauchy.nb
+	} else if ( type == "logitnorm" ) {
+	  nb <- Rfast2::logitnorm.nb
+	} else if ( type == "beta" ) {
+	  nb <- Rfast2::beta.nb
+    } else if ( type == "vm" ) {
+      nb <- Rfast2::vm.nb
+    } else if ( type == "spml" ) {
+      nb <- Rfast2::spml.nb
+	} 
+
+    for ( i in 1:nfolds ) {
+      inatrain <- ina[ -folds[[ i ]] ]    
+      xtrain <- x[ -folds[[ i ]], ]
+      inatest <- ina[ folds[[ i ]] ]    
+      xtest <- x[ folds[[ i ]], ]
+      est <- nb(xnew = xtest, x = xtrain, ina = inatrain)$est
+      if ( pred.ret )  preds[[ i ]] <- est
+      crit[ i ] <- mean( est == inatest )
+    } ##  end  for ( i in 1:nfolds ) {
+ 
+  } else if ( type == "poisson"  | type == "multinom"  |  type == "geom" | type == "bernoulli" ) {
+    if ( type == "poisson" ) {
+      nb <- Rfast::poisson.nb
+    } else if ( type == "multinom" ) {
+      nb <- Rfast::multinom.nb
+    } else if ( type == "geom" ) {
+      nb <- Rfast::geom.nb
+    } else if ( type == "bernoulli" ) {
+      nb <- Rfast2::bernoulli.nb	
+    }
+
+    for ( i in 1:nfolds ) {
+      inatrain <- ina[ -folds[[ i ]] ]    
+      xtrain <- x[ -folds[[ i ]], ]
+      inatest <- ina[ folds[[ i ]] ]    
+      xtest <- x[ folds[[ i ]], ]
+      est <- nb(xnew = xtest, x = xtrain, ina = inatrain)
+      if ( pred.ret )  preds[[ i ]] <- est
+      crit[ i ] <- mean( est == inatest )
+    } ##  end  for ( i in 1:nfolds ) {
+
+  }  ##  end  if ( type == "gaussian" |  type == "gamma" ) {
+
+  list( preds = preds, crit = mean(crit) )
+}  
+  
+    
+
