@@ -5,7 +5,7 @@
 
 SEXP Rfast2_benchmark(SEXP exprsSEXP,SEXP envSEXP,SEXP timSEXP,SEXP indicesSEXP);
 SEXP Rfast2_col_group(SEXP x,SEXP y,SEXP length_uniqueSEXP,SEXP methodSEXP);
-SEXP Rfast2_col_Quantile(SEXP xSEXP,SEXP ProbsSEXP,SEXP parallelSEXP);
+SEXP Rfast2_colQuantile(SEXP xSEXP,SEXP ProbsSEXP,SEXP parallelSEXP);
 SEXP Rfast2_is_upper_tri(SEXP xSEXP,SEXP dgSEXP);
 SEXP Rfast2_is_lower_tri(SEXP xSEXP,SEXP dgSEXP);
 SEXP Rfast2_is_skew_symmetric(SEXP xSEXP);
@@ -13,9 +13,12 @@ SEXP Rfast2_lud(SEXP xSEXP);
 SEXP Rfast2_merge(SEXP xSEXP,SEXP ySEXP);
 SEXP Rfast2_mmpc2(SEXP ySEXP,SEXP xSEXP,SEXP max_kSEXP,SEXP thresholdSEXP,SEXP testSEXP,SEXP Ini,SEXP parallelSEXP,SEXP maxitersSEXP,SEXP tolSEXP,SEXP backwardSEXP);
 SEXP Rfast2_Quantile(SEXP xSEXP,SEXP ProbsSEXP);
-SEXP Rfast2_row_Quantile(SEXP xSEXP,SEXP ProbsSEXP,SEXP parallelSEXP);
+SEXP Rfast2_rowQuantile(SEXP xSEXP,SEXP ProbsSEXP,SEXP parallelSEXP);
 SEXP Rfast2_colTrimMean(SEXP xSEXP,SEXP ProbsSEXP,SEXP parallelSEXP);
 SEXP Rfast2_rowTrimMean(SEXP xSEXP,SEXP ProbsSEXP,SEXP parallelSEXP);
+SEXP Rfast2_Runif(SEXP nSEXP,SEXP minSEXP,SEXP maxSEXP);
+SEXP Rfast2_Sample_int(SEXP nSEXP,SEXP sizeSEXP,SEXP replaceSEXP);
+SEXP Rfast2_Sample(SEXP xSEXP,SEXP sizeSEXP,SEXP replaceSEXP);
 SEXP Rfast2_trimmean(SEXP xSEXP,SEXP aSEXP);
 
 //Manos
@@ -51,7 +54,7 @@ SEXP Rfast2_gamma_reg(SEXP YSEXP, SEXP XSEXP,SEXP modSEXP,SEXP tolSEXP,SEXP maxi
 static const R_CallMethodDef CallEntries[] = {
   {"Rfast2_benchmark", (DL_FUNC) &Rfast2_benchmark, 4},
   {"Rfast2_col_group", (DL_FUNC) &Rfast2_col_group, 4},
-  {"Rfast2_col_Quantile", (DL_FUNC) &Rfast2_col_Quantile, 3},
+  {"Rfast2_colQuantile", (DL_FUNC) &Rfast2_colQuantile, 3},
   {"Rfast2_is_upper_tri", (DL_FUNC) &Rfast2_is_upper_tri, 2},
   {"Rfast2_is_lower_tri", (DL_FUNC) &Rfast2_is_lower_tri, 2},
   {"Rfast2_is_skew_symmetric", (DL_FUNC) &Rfast2_is_skew_symmetric, 1},
@@ -59,9 +62,12 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast2_merge", (DL_FUNC) &Rfast2_merge, 2},
   {"Rfast2_Quantile", (DL_FUNC) &Rfast2_Quantile, 2},
   {"Rfast2_mmpc2", (DL_FUNC) &Rfast2_mmpc2, 10},
-  {"Rfast2_row_Quantile", (DL_FUNC) &Rfast2_row_Quantile, 3},
+  {"Rfast2_rowQuantile", (DL_FUNC) &Rfast2_rowQuantile, 3},
   {"Rfast2_rowTrimMean", (DL_FUNC) &Rfast2_rowTrimMean, 3},
   {"Rfast2_colTrimMean", (DL_FUNC) &Rfast2_colTrimMean, 3},
+  {"Rfast2_Runif", (DL_FUNC) &Rfast2_Runif, 3},
+  {"Rfast2_Sample_int", (DL_FUNC) &Rfast2_Sample_int, 3},
+  {"Rfast2_Sample", (DL_FUNC) &Rfast2_Sample, 3},
   {"Rfast2_trimmean", (DL_FUNC) &Rfast2_trimmean, 2},
 
   {"Rfast2_inter", (DL_FUNC) &Rfast2_inter, 2},
